@@ -444,6 +444,41 @@ const char *ScriptChecks::chkString(Line *line, ScriptImage *img)
 	return chkAllVars(line, img);
 }
 
+const char *ScriptChecks::chkDefine(Line *line, ScriptImage *img)
+{
+        unsigned idx = 0;
+        const char *cp = line->cmd;
+
+        if(!line->argc)
+                return "define requires arguments";
+
+	while(idx < line->argc)
+	{
+		cp = line->args[idx++];
+
+		if(*cp == '=')
+		{
+			++cp;
+			++idx;
+		}
+
+		if(*cp == '%' || *cp == '&')
+			continue;
+
+		if(*cp == '.')
+			++cp;
+
+		cp = strchr(cp, ':');
+		if(cp)
+		{
+			++cp;
+			if(!isdigit(*cp))
+				return "invalid field size used";
+		}
+	}
+	return NULL;
+}
+
 const char *ScriptChecks::chkVarType(Line *line, ScriptImage *img)
 {  
 	if(getMember(line))
@@ -614,7 +649,7 @@ const char *ScriptChecks::chkSet(Line *line, ScriptImage *img)
 	if(cp)
 		return cp;
 
-	if(!useKeywords(line, "=size"))
+	if(!useKeywords(line, "=size=offset"))
 		return "invalid keyword used";
 
 	return chkFirstVar(line, img);	
@@ -704,6 +739,17 @@ const char *ScriptChecks::chkCounter(Line *line, ScriptImage *img)
 	return chkAllVars(line, img);
 }
 
+const char *ScriptChecks::chkTimer(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "timer has no member";
+
+	if(hasKeywords(line))
+		return "keywords not used for this command";
+
+	return chkAllVars(line, img);
+}
+
 const char *ScriptChecks::chkRefArgs(Line *line, ScriptImage *img)
 {
 	if(hasKeywords(line))
