@@ -549,6 +549,7 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	const char *embed = NULL;
 	bool mscmd = false, execflag = false;
 	bool apps = false;
+	bool defs = false;
 	bool ripple = cmds->ripple;
 	bool wrapper = false;
 	merge_t *merge;
@@ -583,6 +584,20 @@ int ScriptCompiler::compile(istream *str, char *name, const char *scrname)
 	if(cp && !stricmp(cp, ".scr"))
 		ripple = false;
 
+#ifdef	WIN32
+	if(cp && !stricmp(cp, ".ini"))
+		ripple = true;
+#endif
+
+	if(cp && !stricmp(cp, ".conf"))
+		ripple = true;
+
+	if(cp && !stricmp(cp, ".def"))
+	{
+		ripple = true;
+		defs = true;
+	}
+
 	if(bm)
 		access = scrPROTECTED;
 
@@ -894,7 +909,7 @@ repname1:
 
 			if((ripple || apps) && *token == '[')
 			{
-				if(use_funcs)
+				if(use_funcs || defs)
 					pmode = "function";
 				else
 					pmode = "public";
