@@ -1439,6 +1439,10 @@ const char *ScriptInterp::getContent(const char *opt)
 		case symNORMAL:
 			snprintf(tmp, 11, "%d", strlen(sym->data));
 			return tmp;
+		case symCOUNTER:
+		case symTIMER:
+			snprintf(tmp, 11, "%ld", atol(sym->data));
+			return tmp;
 		case symINITIAL:
 			return "0";
 		case symPROPERTY:
