@@ -518,14 +518,30 @@ bool ScriptMethods::scrSet(void)
 	bool cat = false;
 	bool rtn;
 	bool pset = false;
-	unsigned ss = stack;
+	unsigned ss = stack, len;
+	int maxsize = 0, pos = 0;
+	char *ep;
 
 	if(opt && isdigit(*opt))
 		size = atoi(opt);
 
 	opt = getKeyword("size");
 	if(opt)
+	{
+		maxsize = atoi(opt);
 		size = atoi(opt);
+	}
+
+	opt = getKeyword("offset");
+	if(opt)
+		pos = atoi(opt);
+
+	if(maxsize < 0)
+	{
+		pos += maxsize;
+		maxsize = -maxsize;
+		size = -maxsize;
+	}
 
 	if(max > 1024)
 		max = 1024;
@@ -556,7 +572,7 @@ bool ScriptMethods::scrSet(void)
 		cat = true;
 	else if(!strnicmp(line->cmd, "init", 4))
 	{
-		if(sym && sym->type != symINITIAL)
+		if(sym && sym->type != symINITIAL && sym->type != symORIGINAL)
 		{
 			skip();
 			return true;
@@ -574,6 +590,31 @@ bool ScriptMethods::scrSet(void)
 	else if(sym->type == symINITIAL)
 		sym->type = symNORMAL;
 
+	len = (unsigned)strlen(opt);
+	if(pos < 0 && -pos > (int)len)
+		pos = 0;
+	else if(pos < 0)
+	{
+		opt = opt + len + pos;
+		len = -pos;
+	}
+	else if(pos >= (int)len)
+		len = 0;
+	else
+	{
+		opt += pos;
+		len -= pos;
+	}
+
+	if(!len)
+		opt = "";
+
+	if(maxsize && (int)len > maxsize)
+	{
+		ep = (char *)opt + maxsize;
+		*ep = 0;
+	}
+
 	if(cat)
 		rtn = append(sym, opt);
 	else
@@ -790,6 +831,40 @@ bool ScriptMethods::scrRestart(void)
 	return true;
 }
 
+bool ScriptMethods::scrTimer(void)
+{
+	const char *err = NULL;
+	Symbol *sym;
+	time_t now;
+	const char *cp;
+
+	time(&now);
+
+	while(NULL != (cp = getOption(NULL)))
+	{
+		sym = mapSymbol(cp, 23);		
+		if(!sym)
+		{
+err:
+			err = "timer-symbol-invalid";
+			continue;
+		}
+		if(sym->type == symINITIAL && sym->size > 22)
+			goto set;
+		if(sym->type == symTIMER)
+			goto set;
+		goto err;
+set:
+		snprintf(sym->data, 12, "%ld", now);
+		sym->type = symTIMER;
+	}
+	if(err)
+		error(err);
+	else
+		skip();
+	return true;
+}
+
 bool ScriptMethods::scrCounter(void)
 {
 	unsigned ival = 0;
@@ -1142,6 +1217,77 @@ bool ScriptMethods::scrType(void)
 	return true;
 }
 
+bool ScriptMethods::scrDefine(void)
+{
+	char var[128];
+	char base[65];
+        Symbol *sym;
+        const char *cp, *pv;
+        const char *prefix = getMember();
+        unsigned len;
+	char *ep;
+	Line *line = getLine();
+	Name *scr = getName();
+	unsigned idx = 0, vlen;
+
+	if(!prefix && !frame[stack].local)
+	{
+		setString(base, sizeof(base), scr->name);
+		ep = strchr(base, ':');
+		if(ep)
+			*ep = 0;
+		prefix = base;
+	}
+
+	while(idx < line->argc)
+	{
+		pv = NULL;
+		cp = line->args[idx++];
+		if(*cp == '=')
+		{
+			pv = line->args[idx++];
+			++cp;
+		}
+		
+		if(prefix && !strchr(cp, '.') && *cp != '%' && *cp != '&')
+	                snprintf(var, sizeof(var), "%s.%s", prefix, cp);
+		else
+			setString(var, sizeof(var), cp);
+
+                ep = strrchr(var, ':');
+                if(ep)
+                {
+                        *(ep++) = 0;
+                        len = atoi(ep);
+                }
+		else if(pv)
+			len = 0;
+		else
+			len = symsize;
+
+		if(!pv)
+			pv = "";
+
+		if(!len)
+			vlen = (unsigned)strlen(pv);
+		else
+			vlen = len;
+
+                sym = mapSymbol(var, vlen);
+		if(!sym || sym->type != symINITIAL)
+			continue;
+
+		setString(sym->data, sym->size + 1, pv);
+		if(len)
+			sym->type = symNORMAL;
+		else
+			sym->type = symCONST;
+
+	}
+	advance();
+	return true;
+}
+
 bool ScriptMethods::scrVar(void)
 {
 	unsigned short size = symsize;
