@@ -108,6 +108,8 @@ ScriptCommand()
 			(Check)&ScriptChecks::chkOnlyCommand},
 		{"counter", true, (Method)&ScriptMethods::scrCounter,
 			(Check)&ScriptChecks::chkCounter},
+		{"timer", true, (Method)&ScriptMethods::scrTimer,
+			(Check)&ScriptChecks::chkTimer},
 		{"index", false, (Method)&ScriptMethods::scrIndex,
 			(Check)&ScriptChecks::chkIndex},
 		{"num", true, (Method)&ScriptMethods::scrNumber,
@@ -125,8 +127,12 @@ ScriptCommand()
 		{"type", true, (Method)&ScriptMethods::scrType,
 			(Check)&ScriptChecks::chkVarType},
                 {"vartype", true, (Method)&ScriptMethods::scrType,
-                        (Check)&ScriptChecks::chkVarType},  
-		{"string", true, (Method)&ScriptMethods::scrVar,
+                        (Check)&ScriptChecks::chkVarType},
+		{"define", true, (Method)&ScriptMethods::scrDefine,
+			(Check)&ScriptChecks::chkDefine},
+                {"symbols", true, (Method)&ScriptMethods::scrDefine,
+                        (Check)&ScriptChecks::chkDefine},
+  		{"string", true, (Method)&ScriptMethods::scrVar,
 			(Check)&ScriptChecks::chkString}, 
                 {"str", true, (Method)&ScriptMethods::scrVar,     
                         (Check)&ScriptChecks::chkString},
@@ -156,6 +162,8 @@ ScriptCommand()
 			(Check)&ScriptChecks::chkIgnore},
 		{"keywords", false, (Method)&ScriptMethods::scrNop,
 			(Check)&ScriptChecks::chkKeywords},
+                {"keyword", false, (Method)&ScriptMethods::scrNop,
+                        (Check)&ScriptChecks::chkKeywords},
 		{"sequence", true, (Method)&ScriptMethods::scrSequence,
 			(Check)&ScriptChecks::chkSequence},
 		{"const", true, (Method)&ScriptMethods::scrConst,
