@@ -79,6 +79,10 @@ bool Script::use_funcs = false;
 const char *Script::plugins = NULL;
 const char *Script::altplugins = NULL;
 
+const char *Script::etc_prefix = ".";
+const char *Script::var_prefix = ".";
+const char *Script::log_prefix = ".";
+
 const char *Script::access_user = NULL;
 const char *Script::access_pass = NULL;
 const char *Script::access_host = "localhost";
@@ -297,6 +301,9 @@ void Script::clear(Symbol *sym)
 		memcpy(&p, &sym->data, sizeof(p));
 		p->clear(sym->data + sizeof(p), sym->size - sizeof(p));
 		return;
+	case symMODIFIED:
+		sym->type = symORIGINAL;
+	case symORIGINAL:
 	case symLOCK:
 	case symNORMAL:
 		if(!stricmp(sym->id, "script.error"))
@@ -311,6 +318,8 @@ void Script::clear(Symbol *sym)
 		sym->data[0] = '0';
 		sym->data[1] = 0;
 		return;	
+	case symTIMER:
+		return;				
 	}
 }
 
@@ -322,6 +331,7 @@ unsigned Script::count(Symbol *sym)
 	{
 	case symCONST:
 	case symCOUNTER:
+	case symTIMER:
 	case symLOCK:
 		return 0;
 	case symARRAY:
@@ -346,6 +356,8 @@ unsigned Script::storage(Symbol *sym)
 		return a->rec;
 	case symPROPERTY:
 		return sym->size - sizeof(ScriptProperty *);
+	case symORIGINAL:
+	case symMODIFIED:
 	case symINITIAL:
 	case symNORMAL:
 		return sym->size;		
@@ -359,6 +371,7 @@ const char *Script::extract(Symbol *sym)
         const char *data;
         unsigned short pos, len;
 	Array *a;
+	time_t now;
 
 	if(!sym)
 		return NULL;
@@ -374,10 +387,16 @@ const char *Script::extract(Symbol *sym)
 		return NULL;
 	case symPROPERTY:
 		return sym->data + sizeof(ScriptProperty *);
+	case symORIGINAL:
+	case symMODIFIED:
 	case symNORMAL:
 	case symCONST:
 	case symNUMBER:
 		return sym->data;
+	case symTIMER:
+		time(&now);
+		snprintf(sym->data + 12, 12, "%ld",  now - atol(sym->data));
+		return sym->data + 12;
 	case symCOUNTER:
 		value = atoi(sym->data);
                 snprintf(sym->data, sym->size + 1, "%ld", ++value);
@@ -430,7 +449,14 @@ bool Script::append(Symbol *sym, const char *value)
 	case symNUMBER:
 	case symPROPERTY:
 	case symCOUNTER:
+	case symTIMER:
 		return false;
+	case symORIGINAL:
+		sym->type = symMODIFIED;
+		sym->data[0] = 0;
+	case symMODIFIED:
+                addString(sym->data, sym->size + 1, value);
+		return true;
 	case symNORMAL:
 	case symINITIAL:
 		addString(sym->data, sym->size + 1, value);
@@ -549,10 +575,19 @@ bool Script::commit(Symbol *sym, const char *value)
 		a->tail = npos;
 		setString(sym->data + sizeof(Array) + (pos * len), len,	value);
 		return true;
+	case symTIMER:
+		val = atol(sym->data) + atol(value);
+		snprintf(sym->data, sym->size + 1, "%ld", val);
+		return true;
 	case symCOUNTER:
 		val = atoi(value);
 		snprintf(sym->data, sym->size + 1, "%ld", --val);
 		return true;
+	case symORIGINAL:
+		sym->type = symMODIFIED;
+	case symMODIFIED:
+		setString(sym->data, sym->size + 1, value);
+		return true;
 	case symNORMAL:
 	case symINITIAL:
 		setString(sym->data, sym->size + 1, value);
