@@ -35,6 +35,12 @@
 // If you do not wish that, delete this exception notice.
 //
 
+/**
+ * @file script3.h
+ * @short Threaded step execute scripting engine framework.
+ **/
+
+
 #ifndef	CCXX_SCRIPT3_H_
 #define	CCXX_SCRIPT3_H_
 
@@ -60,6 +66,7 @@
 #define	SCRIPT_APPS_WRAPPER
 #define	SCRIPT_RIPPLE_LEVEL 2
 #define	SCRIPT_BINDER_SELECT
+#define	SCRIPT_SERVER_PREFIX
 
 #ifndef CCXX_PACKING
 #if defined(__GNUC__)
@@ -129,6 +136,9 @@ public:
 		symNUMBER,
 		symLOCK,
 		symPROPERTY,
+		symORIGINAL,
+		symMODIFIED,
+		symTIMER
 	};
 
 	typedef enum symType symType;
@@ -282,6 +292,10 @@ public:
 	static const char *apps_extensions;
 	static const char *apps_prefix;
 
+	static const char *etc_prefix;
+	static const char *var_prefix;
+	static const char *log_prefix;
+
         static void addFunction(const char *name, unsigned count, Function i);
         static void addConditional(const char *name, Cond test);
 
@@ -308,6 +322,7 @@ public:
 	inline const char *cstring(const char *str)
 		{return MemPager::alloc(str);};
 
+	unsigned gathertype(Symbol **idx, unsigned max, const char *prefix, symType group);
 	unsigned gather(Symbol **idx, unsigned max, const char *prefix, const char *suffix);
 	Symbol *find(const char *id, unsigned short size = 0);
 	Symbol *make(const char *id, unsigned short size);
@@ -391,7 +406,7 @@ public:
 	 * Issue a control event against current image for attached
 	 * modules until claimed.
 	 *
-	 * @param control arguments.
+	 * @param args list of control command and arguments.
 	 * @return true if processed.
 	 */
 	bool control(char **args);
@@ -425,8 +440,9 @@ protected:
 	 * Check keyword syntax.
 	 *
 	 * @return syntax error string or NULL.
-	 * @param name of keyword to check.
-	 * @param hook to compiler source.
+	 * @param command name of keyword to check.
+	 * @param line pointer to line being compiled.
+	 * @param img pointer to image being compiled.
 	 */
 	const char *check(char *command, Line *line, ScriptImage *img);
 
@@ -436,7 +452,7 @@ protected:
 	 * @return trap id number, 0 (exit) if invalid.
 	 * @param name of trap identifier.
 	 */
-	virtual unsigned getTrapId(const char *trap);
+	virtual unsigned getTrapId(const char *name);
 
 	/**
 	 * Get the mask bits for the default script.
@@ -448,16 +464,16 @@ protected:
 	/**
 	 * Get the mask bits for a trap "handler".
 	 *
-	 * @return trap mask to use.
+	 * @return script object of trap mask to use.
 	 */
-	virtual unsigned long getTrapHandler(Name *scr);
+	virtual unsigned long getTrapHandler(Name *script);
   
 	/**
 	 * Get a trap mask for a given identifer.  This is a virtual
 	 * since some derived handlers may manipulate mask bits.
 	 *
-	 * @return signal mask.
-	 * @param identifier.
+	 * @return signal bit mask based on id number.
+	 * @param id number of trap mask.
 	 */
 	virtual unsigned long getTrapMask(unsigned id);
 
@@ -469,7 +485,7 @@ protected:
 	 * @param name of trap identifier.
 	 * @return bit shifted mask or 0 if invalid.
 	 */
-	virtual unsigned long getTrapModifier(const char *trapname);
+	virtual unsigned long getTrapModifier(const char *name);
 
 	/**
 	 * A helper method for the compiler used specifically for
@@ -479,7 +495,7 @@ protected:
 	 * @param name of trap identifier.
 	 * @return bit shifted mask or 0 if invalid.
 	 */
-	virtual unsigned long getTrapMask(const char *trapname);
+	virtual unsigned long getTrapMask(const char *name);
 
 	/**
 	 * Test current command to see if it uses keyword syntax.
@@ -494,10 +510,10 @@ public:
 	 * Test for a specific keyword.
 	 *
 	 * @return content of keyword that is found.
-	 * @param line record to examine in check routine.
+	 * @param line pointer to record to examine in check routine.
 	 * @param keyword to search for.
 	 */
-	static const char *findKeyword(Line *line, const char *kw);
+	static const char *findKeyword(Line *line, const char *keyword);
 
 	/**
 	 * Server level logging interface override.
@@ -505,7 +521,7 @@ public:
 	 * @param level of log message.
 	 * @param text of message.
 	 */
-	virtual void errlog(const char *level, const char *msg);
+	virtual void errlog(const char *level, const char *text);
 
 public:
 	/**
@@ -545,11 +561,11 @@ protected:
 	static bool useMember(Line *line, const char *list);
 
 	/**
-	 * Get an option to examine.
+	 * Get an option to examine in check routine.
 	 *
 	 * @return option or NULL if past end of line record.
-	 * @param line record to examine.
-	 * @param pointer to index.  Start at 0.
+	 * @param line record pointer to line to examine.
+	 * @param index pointer to index value.  Start at 0.
 	 */
 	static const char *getOption(Line *line, unsigned *index);
 
@@ -558,7 +574,7 @@ protected:
 	 * provides a convenient method of initializing and adding to
 	 * the keyword indexes.
 	 *
-	 * @param keyword entries to load.
+	 * @param keywords defined pair entries to load.
 	 */
 	void load(Script::Define *keywords);
 
@@ -567,7 +583,8 @@ protected:
 	 * These are used to handle signal mask coercion and event
 	 * branch points in the compiler.
 	 *
-	 * @param requested trap name.
+	 * @param name of requested trap to add to the trap table.
+	 * @param inherited status of trap.
 	 * @return assigned id number for the trap.
 	 */
 	int trap(const char *name, bool inherited = true);
@@ -589,7 +606,9 @@ protected:
 	 * Perform compile time check of a specified symbol.
 	 *
 	 * @return syntax error message string.
-	 * @param line pointer.
+	 * @param chk object pointer to check member function.
+	 * @param line pointer to line being checked.
+	 * @param img pointer to image being compiled.
 	 */
 	virtual const char *check(Check chk, Line *line, ScriptImage *img);
 
@@ -674,13 +693,16 @@ public:
 	 * A check used by "inc" and "dec".
 	 *
 	 * @return synxtax error message string or NULL.
-	 * @param line statement.
+	 * @param line statement being examined.
+	 * @param img pointer to image being examined.
 	 */
 	const char *chkHasModify(Line *line, ScriptImage *img);
 
 	/**
 	 * Check if member is NULL or a property reference.
 	 *
+	 * @param line pointer to line checked for property reference.
+	 * @param img pointer to image being compiled.
 	 * @return syntax error message string or NULL.
 	 */
 	const char *chkProperty(Line *line, ScriptImage *img);
@@ -688,8 +710,9 @@ public:
 	/**
 	 * A check for first var...
 	 *
-	 * @returbn syntax error message string or NULL.
-	 * @param line statement.
+	 * @return syntax error message string or NULL.
+	 * @param line statement being examined.
+	 * @param img pointer to image being compiled.
 	 */
 	const char *chkFirstVar(Line *line, ScriptImage *img);
 
@@ -697,7 +720,8 @@ public:
 	 * A basic type check for simple type declarations...
 	 *
 	 * @return syntax error message string or NULL.
-	 * @param line statement.
+	 * @param line statement being examined.
+	 * @param img pointer to image being compiled.
 	 */
 	const char *chkType(Line *line, ScriptImage *img);
 
@@ -705,6 +729,10 @@ public:
 	 * Script compiler syntax check for certain variable using
 	 * statements such as "clear".  Assumes list of valid variable
 	 * arguments.
+	 *
+         * @return syntax error message string or NULL.
+         * @param line statement being examined.
+         * @param img pointer to image being compiled.
 	 */
 	const char *chkHasVars(Line *line, ScriptImage *img);
 
@@ -713,7 +741,8 @@ public:
 	 * such as "set", "for", etc.
 	 *
 	 * @return syntax error message string or NULL.
-	 * @param line statement.
+	 * @param line statement being examined.
+	 * @param img pointer to image being compiled.
 	 */
 	const char *chkHasList(Line *line, ScriptImage *img);
 
@@ -722,13 +751,18 @@ public:
 	 * no arguments to be present.
 	 *
 	 * @return syntax error message string or NULL.
-	 * @param line statement.
+	 * @param line statement being examined.
+	 * @param img pointer to image being compiled.
 	 */
 	const char *chkNoArgs(Line *line, ScriptImage *img);
 
 	/**
 	 * Script compiler syntax check for commands that require
 	 * all arguments to be symbols.
+	 *
+	 * @return syntax error message string or NULL.
+	 * @param line pointer being examined.
+	 * @param img pointer to image being compiled.
 	 */
 	const char *chkAllVars(Line *line, ScriptImage *img);
 
@@ -737,13 +771,18 @@ public:
 	 * one or more arguments to be present.
 	 *
 	 * @return syntax error message string or NULL.
-	 * @param line statement.
+	 * @param line statement being examined.
+	 * @param img pointer to image being compiled.
 	 */
 	const char *chkHasArgs(Line *line, ScriptImage *img);
 
 	/**
 	 * Script compiler syntax check for commands that require
 	 * one or more arguments but use no keywords.
+	 *
+         * @return syntax error message string or NULL.
+         * @param line statement being examined.
+         * @param img pointer to image being compiled.
 	 */
 	const char *chkOnlyArgs(Line *line, ScriptImage *img);
 
@@ -811,6 +850,8 @@ public:
 
 	const char *chkCounter(Line *line, ScriptImage *img);
 
+	const char *chkTimer(Line *line, ScriptImage *img);
+
 	const char *chkClear(Line *line, ScriptImage *img);
 
 	const char *chkPack(Line *line, ScriptImage *img);
@@ -820,6 +861,8 @@ public:
 	const char *chkSession(Line *line, ScriptImage *img);
 
 	const char *chkKeywords(Line *line, ScriptImage *img);
+
+	const char *chkDefine(Line *line, ScriptImage *img);
 };
 
 /**
@@ -897,6 +940,8 @@ public:
 
 	/**
 	 * Get current entity being compiled...
+	 *
+	 * @return pointer to script currently compiling.
 	 */
 	inline Name *getCurrent(void)
 		{return current;};
@@ -926,7 +971,7 @@ public:
 	 * Add an advertised route in a priority slot.
 	 *
 	 * @param line statement to add to list.
-	 * @param route add to.
+	 * @param pri of route to add to.
 	 */
 	void addRoute(Line *line, unsigned pri);
 
@@ -966,6 +1011,7 @@ public:
 	 * invoke the compiler as needed.
 	 *
 	 * @param cmdset of keyword table object used.
+	 * @param symset of predefined symbols being used.
 	 */
 	ScriptImage(ScriptCommand *cmdset, const char *symset);
 
@@ -989,23 +1035,23 @@ public:
 	/**
 	 * Used by a derived constructor to load an initialization list.
 	 *
-	 * @param initialization list.
+	 * @param ilist initialization list of symbol pairs to load.
 	 */
 	void load(Initial *ilist);
 
 	/**
 	 * Used to load a single initialization list entry.
 	 *
-	 * @param keyword
-	 * @param value
-	 * @param size
+	 * @param keyword name to initialize.
+	 * @param value of keyword.
+	 * @param size of keyword data field.
 	 */
 	void initial(const char *keyword, const char *value, unsigned size = 0);
 
 	/**
 	 * Fetch named script.
 	 *
-	 * @param script name to find.
+	 * @param name of script to find.
 	 * @return script or NULL.
 	 */
 	virtual Name *getScript(const char *name);
@@ -1029,9 +1075,9 @@ public:
 	/**
 	 * Fetch list of relational scripts.
 	 *
-	 * @param suffix.
-	 * @param index.
-	 * @param max entries.
+	 * @param suffix extension of scripts being fetched.
+	 * @param array of script objects gathered from image.
+	 * @param size limit of array to gather.
 	 * @return count of entries found.
 	 */
 	unsigned gather(const char *suffix, Name **array, unsigned size);
@@ -1115,6 +1161,7 @@ public:
 	 * invoke the compiler as needed.
 	 *
 	 * @param cmdset of keyword table object used.
+	 * @param symset of symbols to set.
 	 */
 	ScriptCompiler(ScriptCommand *cmdset, const char *symset);
 
@@ -1125,7 +1172,7 @@ public:
 	 * @return named script object.
 	 * @param name of script file to compile.
 	 */
-	Name *include(const char *scrfile);
+	Name *include(const char *name);
 
 	/**
 	 * The script compiler itself.  This linearly compiles a Bayonne
@@ -1133,20 +1180,19 @@ public:
 	 * scanner in the constructor.
 	 *
 	 * @return lines of script compiled.
-	 * @param name of script file to compile.
+	 * @param file name of script file to compile.
 	 */
-	int compile(const char *scrfile);
+	int compile(const char *file);
 
 	/**
 	 * Compile a script from disk and give it a different internal
 	 * "name" as passed.
 	 *
 	 * @return lines of script compiled.
-	 * @param name of script file to compile.
-	 * @param name of script to save under.
-	 * @param test if script already loaded.
+	 * @param file name of script file to compile.
+	 * @param name of script to compile under.
 	 */
-	int compile(const char *scrfile, char *name);
+	int compile(const char *file, char *name);
 
 	/**
 	 * Compile an open stream object into a script.
@@ -1154,8 +1200,9 @@ public:
 	 * @return lines of script compiled.
 	 * @param stream object to use.
 	 * @param name of script save under.
+	 * @param file name to use in object.
 	 */
-	int compile(std::istream *str, char *name, const char *scrname = NULL);
+	int compile(std::istream *stream, char *name, const char *file = NULL);
 
 	/**
 	 * Used in the derived constructor to "commit" the current image
@@ -1168,7 +1215,7 @@ public:
 	 * Used to process '$const' inserts.
 	 *
 	 * @return string if found.
-	 * @param script token being substituted.
+	 * @param token string being substituted.
 	 */
 	virtual const char *getDefined(const char *token);
 
@@ -1176,7 +1223,7 @@ public:
 	 * Check for special preprocessor token.
 	 *
 	 * @return error message or NULL if no error.
-	 * @paran name of keyword to check.
+	 * @param token name of keyword to check.
 	 */
 	const char *preproc(const char *token);
 
@@ -1303,7 +1350,7 @@ public:
          * the current or derived class to invoke extensible methods.
          *
          * @return true if immediately ready for next step.      
-         * @param derived method to call.
+         * @param method derived method member to call.
          */
         bool execute(Method method);
 
@@ -1346,7 +1393,7 @@ protected:
         void error(const char *error);  
 
         /**
-         * Events reference to named @event handlers which have been
+         * Events reference to named \@event handlers which have been
          * attached to a script.  This allows low level applications
          * to invoke an event handler much the way a signal handler
          * occurs.
@@ -1355,14 +1402,14 @@ protected:
          * @param name of event handler.
          * @param inhereted search flag.
          */
-        bool scriptEvent(const char *evtname, bool inheret = true);
+        bool scriptEvent(const char *name, bool inhereted = true);
 
 	/**
 	 * Branch to a selected event record immediately.
 	 *
-	 * @param event record.
+	 * @param event record pointer to access.
 	 */
-	void gotoEvent(NamedEvent *ev);
+	void gotoEvent(NamedEvent *event);
 
         /**
          * Set the execution interpreter to a trap identifier.  If no
@@ -1377,7 +1424,7 @@ protected:
 	 * Tries a catch handler...
 	 *
 	 * @return true if caught.
-	 * @param catch handler to try.
+	 * @param id of catch handler to try.
 	 */
 	bool tryCatch(const char *id);
 
@@ -1387,7 +1434,7 @@ protected:
          *
          * @param name of trap to select.
          */
-        void trap(const char *trapname);
+        void trap(const char *name);
 
 public:
 	virtual void logmissing(const char *id, const char *level = "undefined", const char *group = "symbol");
@@ -1446,16 +1493,16 @@ public:
          * @return true if signal handler is not blocked.
          * @param name of signal identifier.
          */
-        bool signal(const char *trapname);
+        bool signal(const char *name);
 
         /**
          * Signals can be referenced by numeric id as well as by symbolic
          * name.
          *
          * @return true if signal handler is not blocked.
-         * @param trap number of handler.
+         * @param id number of handler.
          */
-        bool signal(unsigned trapid);
+        bool signal(unsigned id);
 
 	bool done(void);
 
@@ -1486,6 +1533,7 @@ public:
 	bool scrError(void);
 	bool scrExit(void);
 	bool scrDecimal(void);
+	bool scrDefine(void);
 	bool scrVar(void);
 	bool scrType(void);
 	bool scrNumber(void);
@@ -1515,6 +1563,7 @@ public:
 	bool scrThrow(void);
 	bool scrInvoke(void);
 	bool scrCounter(void);
+	bool scrTimer(void);
 	bool scrCase(void);
 	bool scrEndcase(void);
 	bool scrRemove(void);
@@ -1630,15 +1679,15 @@ public:
          *
          * @param data to save.
          * @param size of data.
-         * @param value.
+         * @param value being set.
          */
-	virtual void setValue(char *data, unsigned short len, long value);
+	virtual void setValue(char *data, unsigned short size, long value);
 
         /**
          * See if should be computed as property.
          *
          * @return true if property valid.
-         * @param string to test.
+         * @param data string to test.
          */
         virtual bool isProperty(const char *data);
 
@@ -1646,8 +1695,8 @@ public:
 	 * Initialize a new property through var definition.
 	 *
 	 * @return property value.
-	 * @param location to save.
-	 * @param optional size of workspace.
+	 * @param data location to clear.
+	 * @param size of workspace to clear.
 	 */
 	virtual void clear(char *data, unsigned size = 0);
 
@@ -1663,7 +1712,7 @@ public:
          *
          * @param data buffer to work from.
          * @param size of data buffer.
-         * @param accumulated offset.
+         * @param adjustment offset to apply.
          */
         virtual void adjust(char *data, size_t size, long adjustment);
 
@@ -1671,14 +1720,15 @@ public:
          * normalize values for scope and range.
          *
          * @return noramized value.
-         * @param original value.
+         * @param value prior to normalization.
          */
 	virtual long adjustValue(long value);
 
         /**
          * Get the "numeric" (or #var) value of this property symbol.
          *
-         * @return size to make.
+         * @return numeric value of this property object.
+	 * @param data being examined from property object.
          */
         virtual long getValue(const char *data);
 
