@@ -122,6 +122,43 @@ unsigned ScriptSymbols::gather(Symbol **idx, unsigned max, const char *prefix, c
 	return count;	
 }
 
+unsigned ScriptSymbols::gathertype(Symbol **idx, unsigned max, const char *prefix, symType type)
+{
+	unsigned key = 0;
+	unsigned count = 0;
+	Symbol *node;
+	
+	if(!prefix)
+		return 0;
+
+	while(max && key <= SCRIPT_INDEX_SIZE)
+	{
+		node = index[key++];
+		while(node && max)
+		{
+			if(strnicmp(node->id, prefix, strlen(prefix)))
+			{
+next:
+				node = node->next;
+				continue;
+			}
+
+			if(node->id[strlen(prefix)] != '.')
+				goto next;
+
+			if(node->type != type)
+				goto next;
+
+			--max;
+			idx[count++] = node;
+			goto next;
+		}
+	}
+	idx[count] = NULL;
+	return count;	
+}
+
+
 Script::Symbol *ScriptSymbols::find(const char *id, unsigned short size)
 {
 	unsigned key;
